@@ -1,16 +1,12 @@
 #!/usr/bin/env bash
 set -xe
-
-# Requires environment CONDA_SHA256, CONDA_VERSION
-
-apt-get update
-apt-get install -y wget bzip2
-
+# Requires environment CONDA_SHA256, CONDA_VERSION, and DEFAULT_ENV
 wget --quiet https://repo.anaconda.com/miniconda/Miniconda3-$CONDA_VERSION-Linux-x86_64.sh
 
 echo "${CONDA_SHA256}  Miniconda3-$CONDA_VERSION-Linux-x86_64.sh" > miniconda.checksum
 
 if [ $(sha256sum -c miniconda.checksum | awk '{print $2}') != "OK" ]; then
+   echo Error when testing checksum
    exit 1;
 fi
 
@@ -19,8 +15,6 @@ sh ./miniconda.sh -b -p /opt/conda
 rm miniconda.sh miniconda.checksum
 
 ln -s /opt/conda/etc/profile.d/conda.sh /etc/profile.d/conda.sh
-echo ". /opt/conda/etc/profile.d/conda.sh" >> ~/.bashrc && \
-echo "conda activate base" >> ~/.bashrc
 
 mkdir -p /etc/conda
 cat <<EOF > /etc/conda/condarc
@@ -30,11 +24,11 @@ auto_update_conda: false
 aggressive_update_packages: []
 envs_dirs:
  - /home/conda/environments
- - /home/jovyan/.conda/envs
+ - /home/qhub_user/.conda/envs
 pkgs_dirs:
- - /home/jovyan/.conda/pkgs
+ - /home/qhub_user/.conda/pkgs
 EOF
 
-apt-get autoremove --purge -y wget bzip2
-apt-get clean
-rm -rf /var/lib/apt/lists/*
+# Fix permissions in accordance with jupyter stack permissions
+# model
+fix-permissions /opt/conda /etc/conda /etc/profile.d
